//LabPlot : PlotTernary.h

#ifndef PLOTTERNARY_H
#define PLOTTERNARY_H

#include "Plot.h"

class PlotTernary:public Plot {
public:
	PlotTernary(Worksheet *p);
	~PlotTernary();
	QStringList Info();
	Axis *getAxis(int) { return &axis; }
	void saveAxes(QTextStream *t);
	void openAxes(QTextStream *t,int version);
	void saveXML(QDomDocument doc, QDomElement plottag);
	void openXML(QDomElement e);
	void draw(QPainter* p,int w, int h);
	void drawCurves(QPainter* p, int w, int h);
/*	void drawAxes(QPainter* p,bool hide);*/
	void setBorder(int, bool) {}
	void setRange(LRange* r,int i) {range[i]=*r;}
	void setActRange(LRange* r,int i) {actrange[i]=*r;}
	void setRanges(LRange* r) {range[0]=r[0];range[1]=r[1];}
	void setActRanges(LRange* r) {actrange[0]=r[0];actrange[1]=r[1];}
private:
	Axis axis;					// only one axis (drawn 3 times)
//	TODO : Label label[3];				// 3 axes label
};

#endif // PLOTTERNARY_H
